#[non_exhaustive]pub struct RoomEncryptionEventContent {
pub algorithm: EventEncryptionAlgorithm,
pub encrypt_state_events: bool,
pub rotation_period_ms: Option<UInt>,
pub rotation_period_msgs: Option<UInt>,
}Expand description
The content of an m.room.encryption event.
Defines how messages sent in this room should be encrypted.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.algorithm: EventEncryptionAlgorithmThe encryption algorithm to be used to encrypt messages sent in this room.
Must be m.megolm.v1.aes-sha2.
encrypt_state_events: boolWhether state events should be encrypted alongside message-like events.
rotation_period_ms: Option<UInt>How long the session should be used before changing it.
uint!(604800000) (a week) is the recommended default.
rotation_period_msgs: Option<UInt>How many messages should be sent before changing the session.
uint!(100) is the recommended default.
Implementations
Sourceimpl RoomEncryptionEventContent
impl RoomEncryptionEventContent
Sourcepub fn new(algorithm: EventEncryptionAlgorithm) -> Self
pub fn new(algorithm: EventEncryptionAlgorithm) -> Self
Creates a new RoomEncryptionEventContent with the given algorithm.
Sourcepub fn with_recommended_defaults() -> Self
pub fn with_recommended_defaults() -> Self
Creates a new RoomEncryptionEventContent with the mandatory algorithm and the recommended
defaults.
Note that changing the values of the fields is not a breaking change and you shouldn’t rely on those specific values.
Sourcepub fn with_encrypted_state(self) -> Self
pub fn with_encrypted_state(self) -> Self
Enable encrypted state as specified in MSC4362.